@@ -57,8 +57,7 @@ regressor_config_dict = {
     'sklearn.ensemble.AdaBoostRegressor': {
         'n_estimators': [100],
         'learning_rate': [1e-3, 1e-2, 1e-1, 0.5, 1.],
-        'loss': ["linear", "square", "exponential"],
-        'max_depth': range(1, 11)
+        'loss': ["linear", "square", "exponential"]
     },
 
     'sklearn.tree.DecisionTreeRegressor': {
@@ -161,9 +160,11 @@ regressor_config_dict = {
 
     'tpot.builtins.OneHotEncoder': {
         'minimum_fraction': [0.05, 0.1, 0.15, 0.2, 0.25],
-        'sparse': [False]
+        'sparse': [False],
+        'threshold': [10]
     },
 
+
     # Selectors
     'sklearn.feature_selection.SelectFwe': {
         'alpha': np.arange(0, 0.05, 0.001),
